#include <libdontpanic.h>

extern int
myanswer()
{
  return answer();
}

void
boot_FooBarBaz()
{
}
